.. hwit-examples documentation master file, created by
   sphinx-quickstart on Sat Jun  9 14:50:30 2012.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Hwit-examples documentation
===========================

Contents:

.. toctree::
   :maxdepth: 2

HWIT forms
~~~~~~~~~~

* actor.hwit
* agent-g3-blank.hwit
* agent-g3-notitle.hwit
* attitude_form.hwit
* basic.hwit
* blank.hwit
* corrugation-3003.hwit
* empty.hwit
* hwit-partial.hwit
* hwit_poll.hwit
* mobilisation.hwit
* osvaldo-3915.hwit
* previsit.hwit
* risky.hwit
* scout_camp.hwit
* small.hwit
* underskirts-3915.hwit

HWIT templates
~~~~~~~~~~~~~~

* agent-g3-blank.tsv
* attitude_form.tsv
* gui_test-template.tsv
* mobilisation.tsv
* scout_camp.tsv

Herewith config files
~~~~~~~~~~~~~~~~~~~~~

* agent_a.cfg
* agent_b.cfg
* agent_c.cfg
